<template>
  <div>
    <el-dialog title="数据查看" :visible.sync="isShow" width="80%" @closed="$emit('closeDataLook')">
      <ul class="tab">
        <li v-for="(m,i) in dataVisibleTitle" :key="i" :class="{active:i===dataVisibleIndex}" @click="handleDataVisibleTab(m,i)">{{m.label}}</li>
      </ul>
      <div style="height: 70vh;overflow-y: auto;">
        <ValueTable ref="ValueTableDataLook" :url="$api.insOrder.selectSampleAndProductByOrderId"
                    :key="upIndex"
                    :componentData="componentDataDataLook"/>
      </div>
    </el-dialog>
    <un-pass-retest-result :retestVisible="retestVisible" :retestInfo="retestInfo" @closeRetestLook="closeRetestLook" v-if="retestVisible"></un-pass-retest-result>
  </div>
</template>

<script>
import ValueTable from "@/components/Table/value-table.vue";
import UnPassRetestResult from "./unPassRetestResult.vue";

export default {
  name: "dataLookVisible",
  // import 引入的组件需要注入到对象中才能使用
  components: {UnPassRetestResult, ValueTable},
  props: {
    dataDialogVisible: {
      type: Boolean,
      default: () => false
    },
    dataLookInfo: {
      type: Object,
      default: () => {}
    },
  },
  data() {
    // 这里存放数据
    return {
      upIndex: 0,
      isShow: this.dataDialogVisible,
      dataVisibleTitle: [
        {
          label: '进厂检验',
          value: 0
        },
        {
          label: '季度检验',
          value: 1
        },
      ],
      dataVisibleIndex: 0, // 数据查看tab栏选择值
      // 表格数据
      componentDataDataLook: { // 数组查看的table数据
        entity: {
          id: null,
        },
        isIndex: false,
        showSelect: false,
        select: false,
        do: [
          {
            id: '',
            font: '不合格复测查看',
            type: 'text',
            method: 'getRetestResult',
            disabFun: (row, index) =>  {
              return row.insResult!=0
            }
          }
        ],
        tagField: {
          insState: {
            select: []
          },
          insResult: {
            select: [{
              value: 1,
              label: '合格',
              type: 'success'
            },{
              value: 0,
              label: '不合格',
              type: 'danger'
            },{
              value: 3,
              label: '不判定',
              type: ''
            }]
          }
        },
        selectField: {},
        requiredAdd: [],
        requiredUp: []
      },
      retestVisible: false,
      retestInfo: []
    }
  },
  mounted() {
    this.refreshTable()
  },
  // 方法集合
  methods: {
    // 切换数据查看tab栏
    handleDataVisibleTab (m, i) {
      this.dataVisibleIndex = i
      this.refreshTable()
    },
    // 查询回调
    refreshTable(e) {
      if (this.dataVisibleIndex === 0) {
        this.componentDataDataLook.entity.id = this.dataLookInfo.enterOrderId
      } else {
        this.componentDataDataLook.entity.id = this.dataLookInfo.quarterOrderId
      }
      this.$nextTick(() => {
        this.$refs['ValueTableDataLook'].selectList(e)
      })
    },
    // 查看不合格复测结果
    getRetestResult (row) {
      this.$axios.get(this.$api.insOrder.getRetestResult+'?insProductId='+row.insProductId).then(res => {
        if (res.code == 201) return
        this.retestVisible = true
        this.retestInfo = res.data
      })
    },
    closeRetestLook () {
      this.retestVisible = false
    },
  },
}
</script>

<style scoped>
.tab {
  list-style-type: none;
  display: flex;
  margin-bottom: 12px;
}

.tab li {
  line-height: 24px;
  padding: 6px 14px;
  font-size: 14px;
  color: #333333;
  border: 1px solid #EEEEEE;
  cursor: pointer;
}

.tab li:nth-child(1) {
  border-radius: 8px 0 0 8px;
}

.tab li:nth-child(2) {
  border-radius: 0 8px 8px 0;
}

.tab li.active {
  border-color: #3A7BFA;
  color: #3A7BFA;
}
</style>
